* 2006_esec88_silc.do
*
* Wirth, Heike/ Gilsbach, Judith (2022): 2006_esec88_silc.do.
* https://www.gesis.org/en/missy/materials/EU-SILC/tools/datahandling
*
* Generates European Socio-economic Classification (ESEC) for EU-SILC Data
* using the EU-SILC P-File (personal data)
*
* For details on ESeC please visit the homepage of Eric Harrison
* http://ekharrison.weebly.com/european-socio-economic-classification-esec.html
*
* This Stata-code is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as
* published by the Free Software Foundation, either version 3 of the
* License, or (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU Affero General Public License for more details.
*
* <https://www.gnu.org/licenses/>.
*
* For transforming the EU-SILC CSV-data (as released by Eurostat) into Stata-data (*.dta),
* please use the corresponding Stata Command Syntax File published at 
* http://www.gesis.org/missy/eu/setups/EU-SILC
*
* (c) GESIS 09/02/2022
* GESIS - Leibniz Institute for the Social Sciences
* German Microdata Lab 
* Heike Wirth/Judith Gilsbach
* https://www.gesis.org/gml/european-microdata/eu-silc/
* http://www.gesis.org/en/institute/
*
* Contact: heike.wirth@gesis.org
***********************************************************************************

/* Initialization commands */
clear
set more off
version 12.0
set linesize 250
set varabbrev off

* ==================================================================================
* CONFIGURATION SECTION - Start 


* The following command should contain the complete path and
* name of the STATA file, usual file extension "dta"

* Change "PATH\P_FILE" to your path & filename (P-FILE)

use "PATH\P_FILE", clear


* CONFIGURATION SECTION - End 
* There should be probably nothing to change below this line 

* ================================================================================== 

numlabel _all, add

************************************************************************************************
* Variables used
* PB020: Country (alphanumeric)
* PL050: ISCO88  (2-digit); PT: coarsend 11,12 = 13)
* PL040: Status in employment
* PL030: self-defined current economic status 
* PL130; PL130_F: Number of Persons working at the local unit; Flag
* PL150: managerial position
* PX040: Respondent status
*
*************************************************************************************************
*  Good to know
*  (1) PL130 is only available for currently economic active persons
*      The ranges used in PL130 categories '14' (don't know but < 11) and '15' (don't know but > 10)
*      are slightly different to the ranges (< 10; >=10) used in ESEC
*  (2) In the so-called register countries, some information is available only for the
*      'selected respondent' (= only one person per household is interviewed)
*      with respect to the variables needed for ESEC this is true PL130 (size ..) and 
*      PL150 (managerial position) 
*
*  => ESEC can only be generated for persons currently economic active
*  => In register countries (DK, FI, IS, NL, NO, SE, SI) ESEC can only be generated for the 
*     'selected respondent'. In all other countries ESEC can be generated for all household
*      members currently economic active
*
*  (3) There are country specific anonymisation rules in EU-SILC for PT 
*      *      PT: ISCO88 sub-major groups 11, 12 are assigned to sub-major group 13
*         
*
*   => ESEC for PT is not fully consistent with ESEC for the other countries
************************************************************************************************

* ESEC 88
* Step 1: derive employment status categories (emplrel)


* a)
* need to know status in employment (self-employed or employed)
* Variable name in EU Silc is PL040
* the newly generated variable is "emplrel"
* Please note: family workers in ESeC are treated as employees

gen emplrel=.

*tab PL040
replace emplrel=1 if (PL040==3)
replace emplrel=1 if (PL040==4) 
replace emplrel=2 if (PL040==1)
replace emplrel=2 if (PL040==2)
label define emplrel_lbl 1 "employee" 2 "self-employed" 
label values emplrel emplrel_lbl 

tab emplrel, m

* b)
* Self-employed were split according to the number of persons working at the local unit
* adequate variable in EU-SILC is PL130 
* generating new variable "emplno".

gen emplno=.
replace emplno=1 if (PL130>=1 & PL130<=9)   
replace emplno=2 if (PL130>=10 & PL130<=13)
replace emplno=1 if (PL130==14)
replace emplno=2 if (PL130==15)

* If PL130 is missing and PL040 equal 1 or equal 2 => emplno = 1'.
replace emplno=1 if (PL130_F == -1 & PL040 == 1)
replace emplno=1 if (PL130_F == -1 & PL040 == 2)

*labels
label define emplno_lbl  1 "<10"  2">=10" 
label values emplno emplno_lbl
tab emplno, m

* c)
* Next differentiation is based on the managerial position
* adequate variable in EU-SILC is PL150
* generating new variable "jbspv"

gen jbspv=2																				
replace jbspv=1 if PL150==1
replace jbspv=2 if PL150==2
label define jbspv_lbl 1 "supervisory" 2 "nonsupervisory"
label values jbspv jbspv_lbl
tab2 PL150 jbspv, m

* d)
* now combine the basic employment situation with the number of persons at the local 
* unit and the managerial position
* generating new variable "empstat".

gen empstat=.
replace empstat=1 if (emplrel==2 & emplno==2) 
replace empstat=2 if (emplrel==2 & emplno==1) 
replace empstat=3 if (emplrel==1 & jbspv==1)
replace empstat=4 if (emplrel==1 & jbspv==2)

*===========================================================================.
*Amendment self-employed without employees.
*===========================================================================.

replace empstat=2 if (PL040 == 2)

label define empstat_lbl 1 "se10+" 2 "se<=10" 3 "sup" 4 "emp"
label values empstat empstat_lbl
tab empstat, m

******************************************************************************************
*** Stage 2: creation of ESEC88 

* A: ESEC88
* for ISCO-88, the corresponding variable in EU-SILC is PL050

gen ESEC88=PL050
*tab ESEC88, m

***blocks of syntax for each employment status variable***

*self-employed 10+
recode ESEC88 ///
1 10 11 12 12 13 21 22 23 24 31 32 33 34 41 42 51 52 61 71 72 73 74 81 82 83 91 92 93 20 30 40 50 60 70 80 90  =1 ///
if (empstat ==1)
*tab ESEC88, m

*self-employed <=10
recode ESEC88 ///
1 11 20 21 22 24  =1 ///
23 31 32 =2 ///
10 12 13 30 33 34 40 41 42 50 51 52 70 71 72 73 74 80 81 82 83 90 91 93 =4  ///
60 61 92 =5 ///
if empstat ==2
*tab ESEC88, m

*supervisors
recode ESEC88 /// 
1 10 11 12 20 21 22 24  =1 ///
13 23 30 31 32 33 34 40 41 42 =2 ///
50 51 52 60 61 70 71 72 73 74 80 81 82 83 90 91 92 93 =6 ///
if empstat==3
*tab ESEC88, m

*employees
recode ESEC88 /// 
1 10 11 12 20 21 22 24 =1 /// 
13 23 31 32 =2 /// 
30 33 34 40 41 42  =3 /// 
73 =6 /// 
50 51 52 =7 /// 
60 61 70 71 72 74 =8 /// 
80 81 82 83 90 91 92 93 =9 /// 
if empstat==4
*tab ESEC88, m

lab def ESEC88 ///
1 "Large employers, higher mgrs/professionals" ///
2 "Lower mgrs/professionals, higher supervisory/technicians" ///
3 "Intermediate occupations" ///
4 "Small employers and self-employed (non-agriculture)" ///
5 "Small employers and self-employed (agriculture)" ///
6 "Lower supervisors and technicians" ///
7 "Lower sales and service"  ///
8 "Lower technical" ///
9 "Routine" ///
-98 "Not selected respondent" ///
-97 "currently not working" ///
-99 "missing information"
lab value ESEC88 ESEC88
tab ESEC88, m
tab empstat, m

**************************************************************************************
* check the new created variables 
recode ESEC88 (. = -99)
recode empstat (. = -99)
*replace empstat = -99 if empstat == .
*replace ESEC88 = -99 if ESEC88 == .
tab2 ESEC88 empstat, m

* PL130 is only available for respondents currently working
* ESeC can be assigned only to respondents with PL030 <3

* PL031 starting with 2009.
recode ESEC88 (-99/99 = -97) if (PL030 >= 3 & PL030 != .)

tab ESEC88, m

* not all variables needed for generating ESEC88 are available for all respondents. This is especially
* true for countries using the concept of "selected respondents"  (DK, FI, IS, NL, NO, SE, SI). In these countries
* the variables PL130 (size ...) and PL150 (managerial status) are available only for selected respondents.
* That is, in these countries ESEC88 should not be generated for PX040 = 3 (not selected respondent) 
* Because in doing so, the ESEC assignments in countries using the selected respondent concept would be biased.


* ESEC for 'not selected respondent' is set to -98 *.
recode ESEC88 (-99/max = -98) if (PX040 == 3)
tab ESEC88

* Finally: due to partly missing information some respondents cannot be assigned to a ESeC class.
recode ESEC88 (10/max = -99)

*add numlabel too all new generated variables
numlabel _all, add

*Define Missing values as Miissing
mvdecode ESEC88, mv(-99 = .a \ -98 = .b \ -97 = .c)

tab ESEC88, m

tab2 PB020 ESEC88
tab2 PB020 ESEC88, row nofreq